@@ -36,9 +36,7 @@ class LoadBinary(QDialog):
         self.arch = partial_ld.main_object.arch
 
         # return values
-        self.cfg_args = None
         self.load_options = None
-        self.variable_recovery_args = None
 
         self.setWindowTitle('Load a new binary')
 
@@ -142,7 +140,6 @@ class LoadBinary(QDialog):
 
     def _init_central_tab(self, tab):
         self._init_load_options_tab(tab)
-        self._init_analysis_options_tab(tab)
 
     def _init_load_options_tab(self, tab):
         arch_layout = QHBoxLayout()
@@ -216,43 +213,6 @@ class LoadBinary(QDialog):
         frame.setLayout(layout)
         tab.addTab(frame, "Loading Options")
 
-    def _init_analysis_options_tab(self, tab):
-        resolve_indirect_jumps = QCheckBox(self)
-        resolve_indirect_jumps.setText('Resolve indirect jumps')
-        resolve_indirect_jumps.setChecked(True)
-        self.option_widgets['resolve_indirect_jumps'] = resolve_indirect_jumps
-
-        collect_data_refs = QCheckBox(self)
-        collect_data_refs.setText('Collect cross references and guess data types')
-        collect_data_refs.setChecked(True)
-        self.option_widgets['data_references'] = collect_data_refs
-
-        xrefs = QCheckBox(self)
-        xrefs.setText('Deep analysis on cross references (slow)')
-        xrefs.setChecked(False)
-        self.option_widgets['cross_references'] = xrefs
-
-        recover_variables_on_matched_functions = QCheckBox(self)
-        recover_variables_on_matched_functions.setText("Recover variables on signature-matched functions")
-        recover_variables_on_matched_functions.setChecked(False)
-        self.option_widgets['recover_variables_on_matched_functions'] = recover_variables_on_matched_functions
-
-        skip_unmapped_addrs = QCheckBox()
-        skip_unmapped_addrs.setText("Skip unmapped addresses")
-        skip_unmapped_addrs.setChecked(True)
-        self.option_widgets['skip_unmapped_addrs'] = skip_unmapped_addrs
-
-        layout = QVBoxLayout()
-        layout.addWidget(resolve_indirect_jumps)
-        layout.addWidget(collect_data_refs)
-        layout.addWidget(xrefs)
-        layout.addWidget(recover_variables_on_matched_functions)
-        layout.addWidget(skip_unmapped_addrs)
-        layout.addStretch(0)
-        frame = QFrame(self)
-        frame.setLayout(layout)
-        tab.addTab(frame, 'Analysis Options')
-
     #
     # Event handlers
     #
@@ -287,22 +247,9 @@ class LoadBinary(QDialog):
         if skip_libs:
             self.load_options['skip_libs'] = skip_libs
 
-        self.cfg_args = {
-            'resolve_indirect_jumps': self.option_widgets['resolve_indirect_jumps'].isChecked(),
-            'data_references': self.option_widgets['data_references'].isChecked(),
-            'cross_references': self.option_widgets['cross_references'].isChecked(),
-            'skip_unmapped_addrs': self.option_widgets['skip_unmapped_addrs'].isChecked()
-        }
-
-        self.variable_recovery_args = {
-            'skip_signature_matched_functions':
-                not self.option_widgets['recover_variables_on_matched_functions'].isChecked(),
-        }
-
         self.close()
 
     def _on_cancel_clicked(self):
-        self.cfg_args = None
         self.close()
 
     @staticmethod
@@ -311,10 +258,7 @@ class LoadBinary(QDialog):
             dialog = LoadBinary(partial_ld)
             dialog.setModal(True)
             dialog.exec_()
-
-            if dialog.cfg_args is not None:
-                # load the binary
-                return dialog.load_options, dialog.cfg_args, dialog.variable_recovery_args
+            return dialog.load_options
         except LoadBinaryError:
             pass
         return None, None, None
