@@ -8,8 +8,10 @@ from .menu import Menu, MenuEntry, MenuSeparator
 class AnalyzeMenu(Menu):
     def __init__(self, main_window):
         super().__init__("&Analyze", parent=main_window)
-
         self.entries.extend([
+            MenuEntry('&Run Analysis...', main_window.run_analysis,
+                      shortcut=QKeySequence(Qt.Key_F4)),
+            MenuSeparator(),
             MenuEntry('&Decompile',
                 main_window.decompile_current_function,
                 shortcut=QKeySequence(Qt.Key_F5)),
